pub struct AddressOfOp { /* private fields */ }Expand description
Same as MLIR’s LLVM dialect AddressOfOp. Creates an SSA value containing a pointer to a global value (function, variable etc).
Results:
| result | description |
|---|---|
result | LLVM pointer type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
global_name | ATTR_KEY_GLOBAL_NAME | IdentifierAttr |
Implementations
Sourceimpl AddressOfOp
impl AddressOfOp
Sourcepub fn get_attr_global_name<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IdentifierAttr>>
pub fn get_attr_global_name<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IdentifierAttr>>
Get a Ref to the value of the attribute named global_name.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_global_name(&self, ctx: &Context, value: IdentifierAttr)
pub fn set_attr_global_name(&self, ctx: &Context, value: IdentifierAttr)
Set the value of the attribute named global_name.
Sourceimpl AddressOfOp
impl AddressOfOp
Sourcepub fn new(ctx: &mut Context, global_name: Identifier) -> Self
pub fn new(ctx: &mut Context, global_name: Identifier) -> Self
Create a new AddressOfOp.
Sourcepub fn get_global_name(&self, ctx: &Context) -> Identifier
pub fn get_global_name(&self, ctx: &Context) -> Identifier
Get the global name that this refers to.
Sourcepub fn get_global(
&self,
ctx: &Context,
symbol_tables: &mut SymbolTableCollection,
) -> Option<GlobalOp>
pub fn get_global( &self, ctx: &Context, symbol_tables: &mut SymbolTableCollection, ) -> Option<GlobalOp>
If this operation referes to a global, get it.
Sourcepub fn get_function(
&self,
ctx: &Context,
symbol_tables: &mut SymbolTableCollection,
) -> Option<FuncOp>
pub fn get_function( &self, ctx: &Context, symbol_tables: &mut SymbolTableCollection, ) -> Option<FuncOp>
If this operation refers to a function, get it.