pub struct AtomicLoadOp { /* private fields */ }Expand description
Equivalent to LLVM’s atomic load.
Operands
| operand | description |
|---|---|
ptr | PointerType |
Result(s):
| result | description |
|---|---|
res | the loaded value |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_ld_ordering | ATTR_KEY_LLVM_LD_ORDERING | AtomicOrderingAttr |
Implementations
Sourceimpl AtomicLoadOp
impl AtomicLoadOp
pub fn get_operand_ptr(&self, ctx: &Context) -> Value
Sourceimpl AtomicLoadOp
impl AtomicLoadOp
Sourcepub fn get_attr_llvm_ld_ordering<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AtomicOrderingAttr>>
pub fn get_attr_llvm_ld_ordering<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AtomicOrderingAttr>>
Get a Ref to the value of the attribute named llvm_ld_ordering.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_ld_ordering(
&self,
ctx: &Context,
value: AtomicOrderingAttr,
)
pub fn set_attr_llvm_ld_ordering( &self, ctx: &Context, value: AtomicOrderingAttr, )
Set the value of the attribute named llvm_ld_ordering.
Sourceimpl AtomicLoadOp
impl AtomicLoadOp
Sourcepub fn new(
ctx: &mut Context,
ptr: Value,
res_ty: TypeHandle,
ordering: AtomicOrderingAttr,
syncscope: SyncScopeAttr,
) -> Self
pub fn new( ctx: &mut Context, ptr: Value, res_ty: TypeHandle, ordering: AtomicOrderingAttr, syncscope: SyncScopeAttr, ) -> Self
Create a new AtomicLoadOp.