pub struct AtomicRmwOp { /* private fields */ }Expand description
Equivalent to LLVM’s atomicrmw: atomically applies kind to the value at
a pointer and returns the old value.
Operands
| operand | description |
|---|---|
ptr | PointerType |
val | value to combine with the one in memory |
Result(s):
| result | description |
|---|---|
res | the old value (same type as val) |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_rmw_kind | ATTR_KEY_LLVM_RMW_KIND | AtomicRmwKindAttr |
llvm_rmw_ordering | ATTR_KEY_LLVM_RMW_ORDERING | AtomicOrderingAttr |
Implementations
Sourceimpl AtomicRmwOp
impl AtomicRmwOp
pub fn get_operand_ptr(&self, ctx: &Context) -> Value
pub fn get_operand_val(&self, ctx: &Context) -> Value
Sourceimpl AtomicRmwOp
impl AtomicRmwOp
Sourcepub fn get_attr_llvm_rmw_kind<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AtomicRmwKindAttr>>
pub fn get_attr_llvm_rmw_kind<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AtomicRmwKindAttr>>
Get a Ref to the value of the attribute named llvm_rmw_kind.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_rmw_kind(&self, ctx: &Context, value: AtomicRmwKindAttr)
pub fn set_attr_llvm_rmw_kind(&self, ctx: &Context, value: AtomicRmwKindAttr)
Set the value of the attribute named llvm_rmw_kind.
Sourcepub fn get_attr_llvm_rmw_ordering<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AtomicOrderingAttr>>
pub fn get_attr_llvm_rmw_ordering<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AtomicOrderingAttr>>
Get a Ref to the value of the attribute named llvm_rmw_ordering.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_rmw_ordering(
&self,
ctx: &Context,
value: AtomicOrderingAttr,
)
pub fn set_attr_llvm_rmw_ordering( &self, ctx: &Context, value: AtomicOrderingAttr, )
Set the value of the attribute named llvm_rmw_ordering.
Sourceimpl AtomicRmwOp
impl AtomicRmwOp
Sourcepub fn new(
ctx: &mut Context,
ptr: Value,
val: Value,
kind: AtomicRmwKindAttr,
ordering: AtomicOrderingAttr,
syncscope: SyncScopeAttr,
) -> Self
pub fn new( ctx: &mut Context, ptr: Value, val: Value, kind: AtomicRmwKindAttr, ordering: AtomicOrderingAttr, syncscope: SyncScopeAttr, ) -> Self
Create a new AtomicRmwOp.