pub struct BlockAddressOp { /* private fields */ }Expand description
Similar to MLIR’s LLVM dialect llvm.blockaddress.
Creates an SSA value containing the address of a tagged block in a function.
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_block_address_function | ATTR_KEY_LLVM_BLOCK_ADDRESS_FUNCTION | [IdentifierAttr] |
llvm_block_address_tag | ATTR_KEY_LLVM_BLOCK_ADDRESS_TAG | [IntegerAttr] |
Implementations
Sourceimpl BlockAddressOp
impl BlockAddressOp
Sourcepub fn get_attr_llvm_block_address_function<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IdentifierAttr>>
pub fn get_attr_llvm_block_address_function<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IdentifierAttr>>
Get a Ref to the value of the attribute named llvm_block_address_function.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_block_address_function(
&self,
ctx: &Context,
value: IdentifierAttr,
)
pub fn set_attr_llvm_block_address_function( &self, ctx: &Context, value: IdentifierAttr, )
Set the value of the attribute named llvm_block_address_function.
Sourcepub fn get_attr_llvm_block_address_tag<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IntegerAttr>>
pub fn get_attr_llvm_block_address_tag<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IntegerAttr>>
Get a Ref to the value of the attribute named llvm_block_address_tag.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_block_address_tag(&self, ctx: &Context, value: IntegerAttr)
pub fn set_attr_llvm_block_address_tag(&self, ctx: &Context, value: IntegerAttr)
Set the value of the attribute named llvm_block_address_tag.
Sourceimpl BlockAddressOp
impl BlockAddressOp
Sourcepub fn new(
ctx: &mut Context,
function_name: Identifier,
tag: u64,
address_space: u32,
) -> Self
pub fn new( ctx: &mut Context, function_name: Identifier, tag: u64, address_space: u32, ) -> Self
Create a new BlockAddressOp referring to a specific block (function_name, tag).
Sourcepub fn get_function_name(&self, ctx: &Context) -> Identifier
pub fn get_function_name(&self, ctx: &Context) -> Identifier
Get the function name of the block that this address refers to.
Sourcepub fn get_tag_id(&self, ctx: &Context) -> u64
pub fn get_tag_id(&self, ctx: &Context) -> u64
Get the tag of the block that this address refers to.
Sourcepub fn get_block_tag_op(
&self,
ctx: &Context,
symbol_tables: &mut SymbolTableCollection,
) -> Option<BlockTagOp>
pub fn get_block_tag_op( &self, ctx: &Context, symbol_tables: &mut SymbolTableCollection, ) -> Option<BlockTagOp>
Get the BlockTagOp that this refers to.
For a well-formed program, this should always return Some(BlockTagOp).