pub struct BlockTagOp { /* private fields */ }Expand description
Similar to MLIR’s LLVM dialect llvm.blocktag.
Marks a basic block with a tag so llvm.blockaddress can refer to it.
A given function should have at most one llvm.blocktag operation with a given tag.
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_block_tag_id | ATTR_KEY_LLVM_BLOCK_TAG_ID | IntegerAttr |
Implementations
Sourceimpl BlockTagOp
impl BlockTagOp
Sourcepub fn get_attr_llvm_block_tag_id<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IntegerAttr>>
pub fn get_attr_llvm_block_tag_id<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IntegerAttr>>
Get a Ref to the value of the attribute named llvm_block_tag_id.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_block_tag_id(&self, ctx: &Context, value: IntegerAttr)
pub fn set_attr_llvm_block_tag_id(&self, ctx: &Context, value: IntegerAttr)
Set the value of the attribute named llvm_block_tag_id.