pub struct CallOp { /* private fields */ }Expand description
Equivalent to LLVM’s Store opcode.
Operands
| operand | description |
|---|---|
callee_operands | Optional function pointer followed by any number of parameters |
Result(s):
| result | description |
|---|---|
res | LLVM type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_call_callee | ATTR_KEY_LLVM_CALL_CALLEE | IdentifierAttr |
llvm_call_fastmath_flags | ATTR_KEY_LLVM_CALL_FASTMATH_FLAGS | FastmathFlagsAttr |
Implementations
Sourceimpl CallOp
impl CallOp
Sourcepub fn get_attr_llvm_call_callee<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IdentifierAttr>>
pub fn get_attr_llvm_call_callee<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IdentifierAttr>>
Get a Ref to the value of the attribute named llvm_call_callee.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_call_callee(&self, ctx: &Context, value: IdentifierAttr)
pub fn set_attr_llvm_call_callee(&self, ctx: &Context, value: IdentifierAttr)
Set the value of the attribute named llvm_call_callee.
Sourcepub fn get_attr_llvm_call_fastmath_flags<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, FastmathFlagsAttr>>
pub fn get_attr_llvm_call_fastmath_flags<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, FastmathFlagsAttr>>
Get a Ref to the value of the attribute named llvm_call_fastmath_flags.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_call_fastmath_flags(
&self,
ctx: &Context,
value: FastmathFlagsAttr,
)
pub fn set_attr_llvm_call_fastmath_flags( &self, ctx: &Context, value: FastmathFlagsAttr, )
Set the value of the attribute named llvm_call_fastmath_flags.