pub struct FCmpOp { /* private fields */ }Expand description
Equivalent to LLVM’same fcmp instruction.
Operand(s):
| operand | description |
|---|---|
lhs | float or vector of float |
rhs | float or vector of float |
Result(s):
| result | description |
|---|---|
res | i1 or vector of i1 |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_fcmp_predicate | ATTR_KEY_LLVM_FCMP_PREDICATE | FCmpPredicateAttr |
Implementations
Sourceimpl FCmpOp
impl FCmpOp
Sourcepub fn get_attr_llvm_fcmp_predicate<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, FCmpPredicateAttr>>
pub fn get_attr_llvm_fcmp_predicate<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, FCmpPredicateAttr>>
Get a Ref to the value of the attribute named llvm_fcmp_predicate.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_fcmp_predicate(
&self,
ctx: &Context,
value: FCmpPredicateAttr,
)
pub fn set_attr_llvm_fcmp_predicate( &self, ctx: &Context, value: FCmpPredicateAttr, )
Set the value of the attribute named llvm_fcmp_predicate.
Sourceimpl FCmpOp
impl FCmpOp
Sourcepub fn new(
ctx: &mut Context,
pred: FCmpPredicateAttr,
lhs: Value,
rhs: Value,
) -> Self
pub fn new( ctx: &mut Context, pred: FCmpPredicateAttr, lhs: Value, rhs: Value, ) -> Self
Create a new FCmpOp
Sourcepub fn predicate(&self, ctx: &Context) -> FCmpPredicateAttr
pub fn predicate(&self, ctx: &Context) -> FCmpPredicateAttr
Get the predicate