pub struct FenceOp { /* private fields */ }Expand description
Equivalent to LLVM’s fence: orders memory accesses. Has no operands or
results.
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_fence_ordering | ATTR_KEY_LLVM_FENCE_ORDERING | AtomicOrderingAttr |
llvm_fence_syncscope | ATTR_KEY_LLVM_FENCE_SYNCSCOPE | StringAttr |
Implementations
Sourceimpl FenceOp
impl FenceOp
Sourcepub fn get_attr_llvm_fence_ordering<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AtomicOrderingAttr>>
pub fn get_attr_llvm_fence_ordering<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AtomicOrderingAttr>>
Get a Ref to the value of the attribute named llvm_fence_ordering.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_fence_ordering(
&self,
ctx: &Context,
value: AtomicOrderingAttr,
)
pub fn set_attr_llvm_fence_ordering( &self, ctx: &Context, value: AtomicOrderingAttr, )
Set the value of the attribute named llvm_fence_ordering.
Sourcepub fn get_attr_llvm_fence_syncscope<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, StringAttr>>
pub fn get_attr_llvm_fence_syncscope<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>
Get a Ref to the value of the attribute named llvm_fence_syncscope.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_fence_syncscope(&self, ctx: &Context, value: StringAttr)
pub fn set_attr_llvm_fence_syncscope(&self, ctx: &Context, value: StringAttr)
Set the value of the attribute named llvm_fence_syncscope.