pub struct GetElementPtrOp { /* private fields */ }Expand description
Equivalent to LLVM’s GetElementPtr.
Operands
| operand | description |
|---|---|
base | LLVM pointer type |
dynamicIndices | Any number of signless integers |
Result(s):
| result | description |
|---|---|
res | LLVM pointer type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_gep_src_elem_type | ATTR_KEY_LLVM_GEP_SRC_ELEM_TYPE | [TypeAttr] |
llvm_gep_indices | ATTR_KEY_LLVM_GEP_INDICES | GepIndicesAttr |
llvm_gep_no_wrap_flags | ATTR_KEY_LLVM_GEP_NO_WRAP_FLAGS | GepNoWrapFlagsAttr |
Implementations
Sourceimpl GetElementPtrOp
impl GetElementPtrOp
pub fn get_operand_src_ptr(&self, ctx: &Context) -> Value
pub fn get_operand_dynamic_indices(&self, ctx: &Context) -> Value
Sourceimpl GetElementPtrOp
impl GetElementPtrOp
Sourcepub fn get_attr_llvm_gep_src_elem_type<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_llvm_gep_src_elem_type<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named llvm_gep_src_elem_type.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_gep_src_elem_type(&self, ctx: &Context, value: TypeAttr)
pub fn set_attr_llvm_gep_src_elem_type(&self, ctx: &Context, value: TypeAttr)
Set the value of the attribute named llvm_gep_src_elem_type.
Sourcepub fn get_attr_llvm_gep_indices<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, GepIndicesAttr>>
pub fn get_attr_llvm_gep_indices<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, GepIndicesAttr>>
Get a Ref to the value of the attribute named llvm_gep_indices.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_gep_indices(&self, ctx: &Context, value: GepIndicesAttr)
pub fn set_attr_llvm_gep_indices(&self, ctx: &Context, value: GepIndicesAttr)
Set the value of the attribute named llvm_gep_indices.
Sourcepub fn get_attr_llvm_gep_no_wrap_flags<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, GepNoWrapFlagsAttr>>
pub fn get_attr_llvm_gep_no_wrap_flags<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, GepNoWrapFlagsAttr>>
Get a Ref to the value of the attribute named llvm_gep_no_wrap_flags.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_gep_no_wrap_flags(
&self,
ctx: &Context,
value: GepNoWrapFlagsAttr,
)
pub fn set_attr_llvm_gep_no_wrap_flags( &self, ctx: &Context, value: GepNoWrapFlagsAttr, )
Set the value of the attribute named llvm_gep_no_wrap_flags.
Sourceimpl GetElementPtrOp
impl GetElementPtrOp
Sourcepub fn new(
ctx: &mut Context,
base: Value,
indices: Vec<GepIndex>,
src_elem_type: TypeHandle,
) -> Self
pub fn new( ctx: &mut Context, base: Value, indices: Vec<GepIndex>, src_elem_type: TypeHandle, ) -> Self
Create a new GetElementPtrOp
Sourcepub fn new_with_no_wrap_flags(
ctx: &mut Context,
base: Value,
indices: Vec<GepIndex>,
src_elem_type: TypeHandle,
no_wrap_flags: GepNoWrapFlags,
) -> Self
pub fn new_with_no_wrap_flags( ctx: &mut Context, base: Value, indices: Vec<GepIndex>, src_elem_type: TypeHandle, no_wrap_flags: GepNoWrapFlags, ) -> Self
Create a new GetElementPtrOp with LLVM no-wrap flags.
Sourcepub fn no_wrap_flags(&self, ctx: &Context) -> GepNoWrapFlags
pub fn no_wrap_flags(&self, ctx: &Context) -> GepNoWrapFlags
Get the GEP no-wrap flags.
Sourcepub fn src_elem_type(&self, ctx: &Context) -> TypeHandle
pub fn src_elem_type(&self, ctx: &Context) -> TypeHandle
Get the source pointer’s element type.
Sourcepub fn indexed_type(
ctx: &Context,
src_elem_type: TypeHandle,
indices: &[GepIndex],
) -> Result<TypeHandle>
pub fn indexed_type( ctx: &Context, src_elem_type: TypeHandle, indices: &[GepIndex], ) -> Result<TypeHandle>
Returns the result element type of a GEP with the given source element type and indexes. See getIndexedType