pub struct GlobalOp { /* private fields */ }Expand description
Same as MLIR’s LLVM dialect GlobalOp It creates a global variable of the specified LLVM IR dialect type. An initializer can be specified either as an attribute or in the operation’s initializer region, ending with a return.
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_global_type | ATTR_KEY_LLVM_GLOBAL_TYPE | TypeAttr |
global_initializer | ATTR_KEY_GLOBAL_INITIALIZER | Any |
llvm_global_linkage | ATTR_KEY_LLVM_GLOBAL_LINKAGE | LinkageAttr |
Implementations
Sourceimpl GlobalOp
impl GlobalOp
Sourcepub fn get_attr_llvm_global_type<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_llvm_global_type<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named llvm_global_type.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_global_type(&self, ctx: &Context, value: TypeAttr)
pub fn set_attr_llvm_global_type(&self, ctx: &Context, value: TypeAttr)
Set the value of the attribute named llvm_global_type.
Sourcepub fn get_attr_global_initializer<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AttrObj>>
pub fn get_attr_global_initializer<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AttrObj>>
Get a Ref to the value of the attribute named global_initializer.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_global_initializer(&self, ctx: &Context, value: AttrObj)
pub fn set_attr_global_initializer(&self, ctx: &Context, value: AttrObj)
Set the value of the attribute named global_initializer.
Sourcepub fn get_attr_llvm_global_linkage<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, LinkageAttr>>
pub fn get_attr_llvm_global_linkage<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, LinkageAttr>>
Get a Ref to the value of the attribute named llvm_global_linkage.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_global_linkage(&self, ctx: &Context, value: LinkageAttr)
pub fn set_attr_llvm_global_linkage(&self, ctx: &Context, value: LinkageAttr)
Set the value of the attribute named llvm_global_linkage.
Sourceimpl GlobalOp
impl GlobalOp
Sourcepub fn get_initializer_value(&self, ctx: &Context) -> Option<AttrObj>
pub fn get_initializer_value(&self, ctx: &Context) -> Option<AttrObj>
Get the initializer value of this global variable.
Sourcepub fn get_initializer_block(&self, ctx: &Context) -> Option<Ptr<BasicBlock>>
pub fn get_initializer_block(&self, ctx: &Context) -> Option<Ptr<BasicBlock>>
Get the initializer region’s block of this global variable. This is a block that ends with a return operation. The return operation must have the same type as the global variable.
Sourcepub fn get_initializer_region(&self, ctx: &Context) -> Option<Ptr<Region>>
pub fn get_initializer_region(&self, ctx: &Context) -> Option<Ptr<Region>>
Get the initializer region of this global variable.
Sourcepub fn set_initializer_value(&self, ctx: &Context, value: AttrObj)
pub fn set_initializer_value(&self, ctx: &Context, value: AttrObj)
Set a simple initializer value for this global variable.
Sourcepub fn add_initializer_region(&self, ctx: &mut Context) -> Ptr<Region>
pub fn add_initializer_region(&self, ctx: &mut Context) -> Ptr<Region>
Add an initializer region (with an entry block) for this global variable. There shouldn’t already be one.