ICmpOp

Struct ICmpOp 

pub struct ICmpOp { /* private fields */ }
Equivalent to LLVM’s ICmp opcode.

Operand(s):

operanddescription
lhsSignless integer or pointer
rhsSignless integer or pointer

Result(s):

resultdescription
res1-bit signless integer

Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
icmp_predicateATTR_KEY_ICMP_PREDICATEICmpPredicateAttr

Implementations

Source

impl ICmpOp

pub fn get_attr_icmp_predicate<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, ICmpPredicateAttr>>

Get a Ref to the value of the attribute named icmp_predicate. The Ref is a borrow of the containing Operation object.

pub fn set_attr_icmp_predicate(&self, ctx: &Context, value: ICmpPredicateAttr)

Set the value of the attribute named icmp_predicate.

Source

impl ICmpOp

pub fn new( ctx: &mut Context, pred: ICmpPredicateAttr, lhs: Value, rhs: Value, ) -> Self

Create a new ICmpOp

pub fn predicate(&self, ctx: &Context) -> ICmpPredicateAttr

Get the predicate