pub struct IndirectBrOp { /* private fields */ }Expand description
Equivalent to LLVM’s IndirectBr opcode.
Operands
| operand | description |
|---|---|
address | PointerType |
dest_opds | variadic of any type, one segment per destination |
Successors:
| Successor | description |
|---|---|
dests | one or more successor(s) |
Implementations
Sourceimpl IndirectBrOp
impl IndirectBrOp
pub fn get_operand_address(&self, ctx: &Context) -> Value
pub fn get_operand_dest_opds(&self, ctx: &Context) -> Value
Sourceimpl IndirectBrOp
impl IndirectBrOp
Sourcepub fn new(
ctx: &mut Context,
address: Value,
dests: Vec<(Ptr<BasicBlock>, Vec<Value>)>,
) -> Self
pub fn new( ctx: &mut Context, address: Value, dests: Vec<(Ptr<BasicBlock>, Vec<Value>)>, ) -> Self
Create a new IndirectBrOp.
Sourcepub fn destinations(&self, ctx: &Context) -> Vec<IndirectBrDest>
pub fn destinations(&self, ctx: &Context) -> Vec<IndirectBrDest>
Get the destinations of this indirectbr operation, along with the operands passed to each.