pub struct SelectOp { /* private fields */ }Expand description
Equivalent to LLVM’s Select opcode.
Operands
| operand | description |
|---|---|
condition | i1 |
true_dest | any type |
false_dest | any type |
Result(s):
| result | description |
|---|---|
res | any type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_select_fast_math_flags | ATTR_KEY_LLVM_SELECT_FAST_MATH_FLAGS | FastmathFlagsAttr |
Implementations
Sourceimpl SelectOp
impl SelectOp
Sourcepub fn get_attr_llvm_select_fast_math_flags<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, FastmathFlagsAttr>>
pub fn get_attr_llvm_select_fast_math_flags<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, FastmathFlagsAttr>>
Get a Ref to the value of the attribute named llvm_select_fast_math_flags.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_select_fast_math_flags(
&self,
ctx: &Context,
value: FastmathFlagsAttr,
)
pub fn set_attr_llvm_select_fast_math_flags( &self, ctx: &Context, value: FastmathFlagsAttr, )
Set the value of the attribute named llvm_select_fast_math_flags.
Sourceimpl SelectOp
impl SelectOp
Sourcepub fn new(
ctx: &mut Context,
cond: Value,
true_val: Value,
false_val: Value,
) -> Self
pub fn new( ctx: &mut Context, cond: Value, true_val: Value, false_val: Value, ) -> Self
Create a new SelectOp.
Sourcepub fn new_with_fast_math_flags(
ctx: &mut Context,
cond: Value,
true_val: Value,
false_val: Value,
fast_math_flags: FastmathFlagsAttr,
) -> Self
pub fn new_with_fast_math_flags( ctx: &mut Context, cond: Value, true_val: Value, false_val: Value, fast_math_flags: FastmathFlagsAttr, ) -> Self
Create a new SelectOp with fast-math flags set.