pub struct ShuffleVectorOp { /* private fields */ }Expand description
ShuffleVectorOp Equivalent to LLVM’s ShuffleVector opcode.
Operands
| operand | description |
|---|---|
vector1 | LLVM vector type |
vector2 | LLVM vector type |
mask | LLVM vector type |
Result(s):
| result | description |
|---|---|
res | LLVM vector type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_shuffle_vector_mask | ATTR_KEY_LLVM_SHUFFLE_VECTOR_MASK | ShuffleVectorMaskAttr |
Implementations
Sourceimpl ShuffleVectorOp
impl ShuffleVectorOp
Sourcepub fn get_attr_llvm_shuffle_vector_mask<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, ShuffleVectorMaskAttr>>
pub fn get_attr_llvm_shuffle_vector_mask<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, ShuffleVectorMaskAttr>>
Get a Ref to the value of the attribute named llvm_shuffle_vector_mask.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_shuffle_vector_mask(
&self,
ctx: &Context,
value: ShuffleVectorMaskAttr,
)
pub fn set_attr_llvm_shuffle_vector_mask( &self, ctx: &Context, value: ShuffleVectorMaskAttr, )
Set the value of the attribute named llvm_shuffle_vector_mask.