SwitchOp

Struct SwitchOp 

pub struct SwitchOp { /* private fields */ }
Equivalent to LLVM’s Switch opcode.

Operands

operanddescription
condition1-bit signless integer
default_dest_opdsvariadic of any type
case_dest_opdsvariadic of any type

Successors:

Successordescription
default_destany successor
case_destsany successor(s)

Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
switch_case_valuesATTR_KEY_SWITCH_CASE_VALUESCaseValuesAttr

Implementations

Source

impl SwitchOp

pub fn get_attr_switch_case_values<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, CaseValuesAttr>>

Get a Ref to the value of the attribute named switch_case_values. The Ref is a borrow of the containing Operation object.

pub fn set_attr_switch_case_values(&self, ctx: &Context, value: CaseValuesAttr)

Set the value of the attribute named switch_case_values.

Source

impl SwitchOp

pub fn new( ctx: &mut Context, condition: Value, default_dest: Ptr<BasicBlock>, default_dest_opds: Vec<Value>, cases: Vec<SwitchCase>, ) -> Self

Create a new SwitchOp.

pub fn cases(&self, ctx: &Context) -> Vec<SwitchCase>

Get the cases of this switch operation. (The default case cannot be / isn’t included here).

pub fn condition(&self, ctx: &Context) -> Value

Get the condition value for the switch.

pub fn default_dest(&self, ctx: &Context) -> Ptr<BasicBlock>

Get the default destination of this switch operation.

pub fn default_dest_operands(&self, ctx: &Context) -> Vec<Value>

Get the operands to pass to the default destination.