AllocaOp

Struct AllocaOp 

pub struct AllocaOp { /* private fields */ }
Equivalent to LLVM’s Alloca opcode.

Operands

operanddescription
array_sizeSignless integer

Result(s):

resultdescription
resPointerType

Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
alloca_element_typeATTR_KEY_ALLOCA_ELEMENT_TYPETypeAttr

Implementations

Source

impl AllocaOp

pub fn get_attr_alloca_element_type<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>

Get a Ref to the value of the attribute named alloca_element_type. The Ref is a borrow of the containing Operation object.

pub fn set_attr_alloca_element_type(&self, ctx: &Context, value: TypeAttr)

Set the value of the attribute named alloca_element_type.

Source

impl AllocaOp

pub fn new(ctx: &mut Context, elem_type: Ptr<TypeObj>, size: Value) -> Self

Create a new AllocaOp