pub struct AllocaOp { /* private fields */ }Expand description
Equivalent to LLVM’s Alloca opcode.
Operands
| operand | description |
|---|---|
array_size | Signless integer |
Result(s):
| result | description |
|---|---|
res | PointerType |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
alloca_element_type | ATTR_KEY_ALLOCA_ELEMENT_TYPE | TypeAttr |
Implementations
Sourceimpl AllocaOp
impl AllocaOp
Sourcepub fn get_attr_alloca_element_type<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_alloca_element_type<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named alloca_element_type.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_alloca_element_type(&self, ctx: &Context, value: TypeAttr)
pub fn set_attr_alloca_element_type(&self, ctx: &Context, value: TypeAttr)
Set the value of the attribute named alloca_element_type.