pub struct AtomicCmpxchgOp { /* private fields */ }Expand description
Equivalent to LLVM’s cmpxchg: atomically compares the value at a pointer
with cmp and, if equal, stores new. Returns a { value, i1 } pair of the
loaded value and whether the swap succeeded.
Operands
| operand | description |
|---|---|
ptr | PointerType |
cmp | expected value |
new | value to store on success |
Result(s):
| result | description |
|---|---|
res | { value, i1 } (loaded value, success flag) |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_cas_success_ordering | ATTR_KEY_LLVM_CAS_SUCCESS_ORDERING | AtomicOrderingAttr |
llvm_cas_failure_ordering | ATTR_KEY_LLVM_CAS_FAILURE_ORDERING | AtomicOrderingAttr |
llvm_cas_syncscope | ATTR_KEY_LLVM_CAS_SYNCSCOPE | StringAttr |
Implementations
Sourceimpl AtomicCmpxchgOp
impl AtomicCmpxchgOp
pub fn get_operand_ptr(&self, ctx: &Context) -> Value
pub fn get_operand_cmp(&self, ctx: &Context) -> Value
pub fn get_operand_new_val(&self, ctx: &Context) -> Value
Sourceimpl AtomicCmpxchgOp
impl AtomicCmpxchgOp
Sourcepub fn get_attr_llvm_cas_success_ordering<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AtomicOrderingAttr>>
pub fn get_attr_llvm_cas_success_ordering<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AtomicOrderingAttr>>
Get a Ref to the value of the attribute named llvm_cas_success_ordering.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_cas_success_ordering(
&self,
ctx: &Context,
value: AtomicOrderingAttr,
)
pub fn set_attr_llvm_cas_success_ordering( &self, ctx: &Context, value: AtomicOrderingAttr, )
Set the value of the attribute named llvm_cas_success_ordering.
Sourcepub fn get_attr_llvm_cas_failure_ordering<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AtomicOrderingAttr>>
pub fn get_attr_llvm_cas_failure_ordering<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AtomicOrderingAttr>>
Get a Ref to the value of the attribute named llvm_cas_failure_ordering.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_cas_failure_ordering(
&self,
ctx: &Context,
value: AtomicOrderingAttr,
)
pub fn set_attr_llvm_cas_failure_ordering( &self, ctx: &Context, value: AtomicOrderingAttr, )
Set the value of the attribute named llvm_cas_failure_ordering.
Sourcepub fn get_attr_llvm_cas_syncscope<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, StringAttr>>
pub fn get_attr_llvm_cas_syncscope<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>
Get a Ref to the value of the attribute named llvm_cas_syncscope.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_cas_syncscope(&self, ctx: &Context, value: StringAttr)
pub fn set_attr_llvm_cas_syncscope(&self, ctx: &Context, value: StringAttr)
Set the value of the attribute named llvm_cas_syncscope.
Sourceimpl AtomicCmpxchgOp
impl AtomicCmpxchgOp
Sourcepub fn new(
ctx: &mut Context,
ptr: Value,
cmp: Value,
new_val: Value,
success_ordering: AtomicOrderingAttr,
failure_ordering: AtomicOrderingAttr,
syncscope: Option<String>,
) -> Self
pub fn new( ctx: &mut Context, ptr: Value, cmp: Value, new_val: Value, success_ordering: AtomicOrderingAttr, failure_ordering: AtomicOrderingAttr, syncscope: Option<String>, ) -> Self
Create a new AtomicCmpxchgOp. syncscope is None for the system scope.