pub struct AtomicStoreOp { /* private fields */ }Expand description
Equivalent to LLVM’s atomic store.
Operands
| operand | description |
|---|---|
val | value to store |
ptr | PointerType |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_st_ordering | ATTR_KEY_LLVM_ST_ORDERING | AtomicOrderingAttr |
llvm_st_syncscope | ATTR_KEY_LLVM_ST_SYNCSCOPE | StringAttr |
Implementations
Sourceimpl AtomicStoreOp
impl AtomicStoreOp
pub fn get_operand_value(&self, ctx: &Context) -> Value
pub fn get_operand_ptr(&self, ctx: &Context) -> Value
Sourceimpl AtomicStoreOp
impl AtomicStoreOp
Sourcepub fn get_attr_llvm_st_ordering<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AtomicOrderingAttr>>
pub fn get_attr_llvm_st_ordering<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AtomicOrderingAttr>>
Get a Ref to the value of the attribute named llvm_st_ordering.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_st_ordering(
&self,
ctx: &Context,
value: AtomicOrderingAttr,
)
pub fn set_attr_llvm_st_ordering( &self, ctx: &Context, value: AtomicOrderingAttr, )
Set the value of the attribute named llvm_st_ordering.
Sourcepub fn get_attr_llvm_st_syncscope<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, StringAttr>>
pub fn get_attr_llvm_st_syncscope<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>
Get a Ref to the value of the attribute named llvm_st_syncscope.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_st_syncscope(&self, ctx: &Context, value: StringAttr)
pub fn set_attr_llvm_st_syncscope(&self, ctx: &Context, value: StringAttr)
Set the value of the attribute named llvm_st_syncscope.
Sourceimpl AtomicStoreOp
impl AtomicStoreOp
Sourcepub fn new(
ctx: &mut Context,
value: Value,
ptr: Value,
ordering: AtomicOrderingAttr,
syncscope: Option<String>,
) -> Self
pub fn new( ctx: &mut Context, value: Value, ptr: Value, ordering: AtomicOrderingAttr, syncscope: Option<String>, ) -> Self
Create a new AtomicStoreOp. syncscope is None for the system scope.