pub struct CallIntrinsicOp { /* private fields */ }Expand description
All LLVM intrinsic calls are represented by this Op. Same as MLIR’s llvm.call_intrinsic.
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_intrinsic_name | ATTR_KEY_LLVM_INTRINSIC_NAME | StringAttr |
llvm_intrinsic_type | ATTR_KEY_LLVM_INTRINSIC_TYPE | TypeAttr |
llvm_intrinsic_fastmath_flags | ATTR_KEY_LLVM_INTRINSIC_FASTMATH_FLAGS | FastmathFlagsAttr |
Implementations
Sourceimpl CallIntrinsicOp
impl CallIntrinsicOp
Sourcepub fn get_attr_llvm_intrinsic_name<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, StringAttr>>
pub fn get_attr_llvm_intrinsic_name<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>
Get a Ref to the value of the attribute named llvm_intrinsic_name.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_intrinsic_name(&self, ctx: &Context, value: StringAttr)
pub fn set_attr_llvm_intrinsic_name(&self, ctx: &Context, value: StringAttr)
Set the value of the attribute named llvm_intrinsic_name.
Sourcepub fn get_attr_llvm_intrinsic_type<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_llvm_intrinsic_type<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named llvm_intrinsic_type.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_intrinsic_type(&self, ctx: &Context, value: TypeAttr)
pub fn set_attr_llvm_intrinsic_type(&self, ctx: &Context, value: TypeAttr)
Set the value of the attribute named llvm_intrinsic_type.
Sourcepub fn get_attr_llvm_intrinsic_fastmath_flags<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, FastmathFlagsAttr>>
pub fn get_attr_llvm_intrinsic_fastmath_flags<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, FastmathFlagsAttr>>
Get a Ref to the value of the attribute named llvm_intrinsic_fastmath_flags.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_intrinsic_fastmath_flags(
&self,
ctx: &Context,
value: FastmathFlagsAttr,
)
pub fn set_attr_llvm_intrinsic_fastmath_flags( &self, ctx: &Context, value: FastmathFlagsAttr, )
Set the value of the attribute named llvm_intrinsic_fastmath_flags.
Sourceimpl CallIntrinsicOp
impl CallIntrinsicOp
Sourcepub fn new(
ctx: &mut Context,
intrinsic_name: StringAttr,
intrinsic_type: TypePtr<FuncType>,
operands: Vec<Value>,
) -> Self
pub fn new( ctx: &mut Context, intrinsic_name: StringAttr, intrinsic_type: TypePtr<FuncType>, operands: Vec<Value>, ) -> Self
Create a new CallIntrinsicOp.