pub struct ConstantOp { /* private fields */ }Expand description
Constant value operation for the LLVM dialect. Similar to MLIR’s llvm.mlir.constant.
The constant value is held as one of the following attributes: [IntegerAttr], dyn FloatAttr, AggregateAttr SplatAttr, BytesAttr, SymbolAddrAttr.
Results:
| result | description |
|---|---|
result | the type of the value attribute |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_constant_value | ATTR_KEY_LLVM_CONSTANT_VALUE | Any |
Implementations
Sourceimpl ConstantOp
impl ConstantOp
Sourcepub fn get_attr_llvm_constant_value<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AttrObj>>
pub fn get_attr_llvm_constant_value<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AttrObj>>
Get a Ref to the value of the attribute named llvm_constant_value.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_constant_value(&self, ctx: &Context, value: AttrObj)
pub fn set_attr_llvm_constant_value(&self, ctx: &Context, value: AttrObj)
Set the value of the attribute named llvm_constant_value.
Sourceimpl ConstantOp
impl ConstantOp
Sourcepub fn get_value<'a>(&self, ctx: &'a Context) -> Ref<'a, dyn TypedAttrInterface>
pub fn get_value<'a>(&self, ctx: &'a Context) -> Ref<'a, dyn TypedAttrInterface>
Get the constant value that this Op defines. The Ref is a borrow of the containing [Operation] object.
Use pliron::dyn_clone::clone_box to clone the value if required.
Sourcepub fn new(ctx: &mut Context, value: Box<dyn TypedAttrInterface>) -> Self
pub fn new(ctx: &mut Context, value: Box<dyn TypedAttrInterface>) -> Self
Create a new ConstantOp holding value.