pub struct ConstantOp { /* private fields */ }Expand description
Numeric (integer or floating point) constant. See MLIR’s llvm.mlir.constant.
Results:
| result | description |
|---|---|
result | any type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
constant_value | ATTR_KEY_CONSTANT_VALUE | Any |
Implementations
Sourceimpl ConstantOp
impl ConstantOp
Sourcepub fn get_attr_constant_value<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, AttrObj>>
pub fn get_attr_constant_value<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, AttrObj>>
Get a Ref to the value of the attribute named constant_value.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_constant_value(&self, ctx: &Context, value: AttrObj)
pub fn set_attr_constant_value(&self, ctx: &Context, value: AttrObj)
Set the value of the attribute named constant_value.