ExtractValueOp

Struct ExtractValueOp 

pub struct ExtractValueOp { /* private fields */ }
Equivalent to LLVM’s ExtractValue opcode.

Operands

operanddescription
aggregateLLVM aggregate type

Result(s):

resultdescription
resLLVM type

Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
extract_value_indicesATTR_KEY_EXTRACT_VALUE_INDICESInsertExtractValueIndicesAttr

Implementations

Source

impl ExtractValueOp

pub fn get_attr_extract_value_indices<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, InsertExtractValueIndicesAttr>>

Get a Ref to the value of the attribute named extract_value_indices. The Ref is a borrow of the containing Operation object.

pub fn set_attr_extract_value_indices( &self, ctx: &Context, value: InsertExtractValueIndicesAttr, )

Set the value of the attribute named extract_value_indices.

Source

impl ExtractValueOp

pub fn new( ctx: &mut Context, aggregate: Value, indices: Vec<u32>, ) -> Result<Self>

Create a new ExtractValueOp. aggregate is the aggregate type and indices is the list of indices to extract the value from. The indices must be valid for the given aggregate type. The result type of the operation is the type of the value at the given indices.

pub fn indices(&self, ctx: &Context) -> Vec<u32>

Get the indices for extracting value from aggregate.

pub fn indexed_type( ctx: &Context, aggr_type: Ptr<TypeObj>, indices: &[u32], ) -> Result<Ptr<TypeObj>>

Returns the type of the value at the given indices in the given aggregate type.