pub struct ExtractValueOp { /* private fields */ }Expand description
Equivalent to LLVM’s ExtractValue opcode.
Operands
| operand | description |
|---|---|
aggregate | LLVM aggregate type |
Result(s):
| result | description |
|---|---|
res | LLVM type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
extract_value_indices | ATTR_KEY_EXTRACT_VALUE_INDICES | InsertExtractValueIndicesAttr |
Implementations
Sourceimpl ExtractValueOp
impl ExtractValueOp
Sourcepub fn get_attr_extract_value_indices<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, InsertExtractValueIndicesAttr>>
pub fn get_attr_extract_value_indices<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, InsertExtractValueIndicesAttr>>
Get a Ref to the value of the attribute named extract_value_indices.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_extract_value_indices(
&self,
ctx: &Context,
value: InsertExtractValueIndicesAttr,
)
pub fn set_attr_extract_value_indices( &self, ctx: &Context, value: InsertExtractValueIndicesAttr, )
Set the value of the attribute named extract_value_indices.
Sourceimpl ExtractValueOp
impl ExtractValueOp
Sourcepub fn new(
ctx: &mut Context,
aggregate: Value,
indices: Vec<u32>,
) -> Result<Self>
pub fn new( ctx: &mut Context, aggregate: Value, indices: Vec<u32>, ) -> Result<Self>
Create a new ExtractValueOp.
aggregate is the aggregate type and indices is the list of indices to extract the value from.
The indices must be valid for the given aggregate type.
The result type of the operation is the type of the value at the given indices.