pub struct FCmpOp { /* private fields */ }Expand description
Equivalent to LLVM’same fcmp instruction.
Operand(s):
| operand | description |
|---|---|
lhs | float |
rhs | float |
Result(s):
| result | description |
|---|---|
res | 1-bit signless integer |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
fcmp_predicate | ATTR_KEY_FCMP_PREDICATE | FCmpPredicateAttr |
Implementations
Sourceimpl FCmpOp
impl FCmpOp
Sourcepub fn get_attr_fcmp_predicate<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, FCmpPredicateAttr>>
pub fn get_attr_fcmp_predicate<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, FCmpPredicateAttr>>
Get a Ref to the value of the attribute named fcmp_predicate.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_fcmp_predicate(&self, ctx: &Context, value: FCmpPredicateAttr)
pub fn set_attr_fcmp_predicate(&self, ctx: &Context, value: FCmpPredicateAttr)
Set the value of the attribute named fcmp_predicate.