FuncOp

Struct FuncOp 

pub struct FuncOp { /* private fields */ }
Equivalent to LLVM’s func operation. See llvm.func.

Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
llvm_func_typeATTR_KEY_LLVM_FUNC_TYPETypeAttr
llvm_function_linkageATTR_KEY_LLVM_FUNCTION_LINKAGELinkageAttr

Implementations

Source

impl FuncOp

pub fn get_attr_llvm_func_type<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>

Get a Ref to the value of the attribute named llvm_func_type. The Ref is a borrow of the containing Operation object.

pub fn set_attr_llvm_func_type(&self, ctx: &Context, value: TypeAttr)

Set the value of the attribute named llvm_func_type.

pub fn get_attr_llvm_function_linkage<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, LinkageAttr>>

Get a Ref to the value of the attribute named llvm_function_linkage. The Ref is a borrow of the containing Operation object.

pub fn set_attr_llvm_function_linkage(&self, ctx: &Context, value: LinkageAttr)

Set the value of the attribute named llvm_function_linkage.

Source

impl FuncOp

pub fn new(ctx: &mut Context, name: Identifier, ty: TypePtr<FuncType>) -> Self

Create a new empty FuncOp.

pub fn get_type(&self, ctx: &Context) -> TypePtr<FuncType>

Get the function signature (type).

pub fn get_entry_block(&self, ctx: &Context) -> Option<Ptr<BasicBlock>>

Get the entry block (if it exists) of this function.

pub fn get_or_create_entry_block(&self, ctx: &mut Context) -> Ptr<BasicBlock>

Get the entry block of this function, creating it if it does not exist.