pub struct FuncOp { /* private fields */ }Expand description
Equivalent to LLVM’s func operation.
See llvm.func.
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
llvm_func_type | ATTR_KEY_LLVM_FUNC_TYPE | TypeAttr |
llvm_function_linkage | ATTR_KEY_LLVM_FUNCTION_LINKAGE | LinkageAttr |
Implementations
Sourceimpl FuncOp
impl FuncOp
Sourcepub fn get_attr_llvm_func_type<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_llvm_func_type<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named llvm_func_type.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_func_type(&self, ctx: &Context, value: TypeAttr)
pub fn set_attr_llvm_func_type(&self, ctx: &Context, value: TypeAttr)
Set the value of the attribute named llvm_func_type.
Sourcepub fn get_attr_llvm_function_linkage<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, LinkageAttr>>
pub fn get_attr_llvm_function_linkage<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, LinkageAttr>>
Get a Ref to the value of the attribute named llvm_function_linkage.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_llvm_function_linkage(&self, ctx: &Context, value: LinkageAttr)
pub fn set_attr_llvm_function_linkage(&self, ctx: &Context, value: LinkageAttr)
Set the value of the attribute named llvm_function_linkage.
Sourceimpl FuncOp
impl FuncOp
Sourcepub fn new(ctx: &mut Context, name: Identifier, ty: TypePtr<FuncType>) -> Self
pub fn new(ctx: &mut Context, name: Identifier, ty: TypePtr<FuncType>) -> Self
Create a new empty FuncOp.
Sourcepub fn get_entry_block(&self, ctx: &Context) -> Option<Ptr<BasicBlock>>
pub fn get_entry_block(&self, ctx: &Context) -> Option<Ptr<BasicBlock>>
Get the entry block (if it exists) of this function.
Sourcepub fn get_or_create_entry_block(&self, ctx: &mut Context) -> Ptr<BasicBlock>
pub fn get_or_create_entry_block(&self, ctx: &mut Context) -> Ptr<BasicBlock>
Get the entry block of this function, creating it if it does not exist.