pub struct GetElementPtrOp { /* private fields */ }Expand description
Equivalent to LLVM’s GetElementPtr.
Operands
| operand | description |
|---|---|
base | LLVM pointer type |
dynamicIndices | Any number of signless integers |
Result(s):
| result | description |
|---|---|
res | LLVM pointer type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
gep_src_elem_type | ATTR_KEY_GEP_SRC_ELEM_TYPE | TypeAttr |
gep_indices | ATTR_KEY_GEP_INDICES | GepIndicesAttr |
Implementations
Sourceimpl GetElementPtrOp
impl GetElementPtrOp
Sourcepub fn get_attr_gep_src_elem_type<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, TypeAttr>>
pub fn get_attr_gep_src_elem_type<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, TypeAttr>>
Get a Ref to the value of the attribute named gep_src_elem_type.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_gep_src_elem_type(&self, ctx: &Context, value: TypeAttr)
pub fn set_attr_gep_src_elem_type(&self, ctx: &Context, value: TypeAttr)
Set the value of the attribute named gep_src_elem_type.
Sourcepub fn get_attr_gep_indices<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, GepIndicesAttr>>
pub fn get_attr_gep_indices<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, GepIndicesAttr>>
Get a Ref to the value of the attribute named gep_indices.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_gep_indices(&self, ctx: &Context, value: GepIndicesAttr)
pub fn set_attr_gep_indices(&self, ctx: &Context, value: GepIndicesAttr)
Set the value of the attribute named gep_indices.
Sourceimpl GetElementPtrOp
impl GetElementPtrOp
Sourcepub fn new(
ctx: &mut Context,
base: Value,
indices: Vec<GepIndex>,
src_elem_type: Ptr<TypeObj>,
) -> Self
pub fn new( ctx: &mut Context, base: Value, indices: Vec<GepIndex>, src_elem_type: Ptr<TypeObj>, ) -> Self
Create a new GetElementPtrOp
Sourcepub fn src_elem_type(&self, ctx: &Context) -> Ptr<TypeObj>
pub fn src_elem_type(&self, ctx: &Context) -> Ptr<TypeObj>
Get the source pointer’s element type.
Sourcepub fn indexed_type(
ctx: &Context,
src_elem_type: Ptr<TypeObj>,
indices: &[GepIndex],
) -> Result<Ptr<TypeObj>>
pub fn indexed_type( ctx: &Context, src_elem_type: Ptr<TypeObj>, indices: &[GepIndex], ) -> Result<Ptr<TypeObj>>
Returns the result element type of a GEP with the given source element type and indexes. See getIndexedType