pub struct ICmpOp { /* private fields */ }Expand description
Equivalent to LLVM’s ICmp opcode.
Operand(s):
| operand | description |
|---|---|
lhs | Signless integer or pointer |
rhs | Signless integer or pointer |
Result(s):
| result | description |
|---|---|
res | 1-bit signless integer |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
icmp_predicate | ATTR_KEY_ICMP_PREDICATE | ICmpPredicateAttr |
Implementations
Sourceimpl ICmpOp
impl ICmpOp
Sourcepub fn get_attr_icmp_predicate<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, ICmpPredicateAttr>>
pub fn get_attr_icmp_predicate<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, ICmpPredicateAttr>>
Get a Ref to the value of the attribute named icmp_predicate.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_icmp_predicate(&self, ctx: &Context, value: ICmpPredicateAttr)
pub fn set_attr_icmp_predicate(&self, ctx: &Context, value: ICmpPredicateAttr)
Set the value of the attribute named icmp_predicate.