pub struct InlineAsmOp { /* private fields */ }Expand description
Equivalent to LLVM’s inline assembly call. The template and constraint
strings follow LLVM’s inline-asm syntax; convergent marks asm that must
not be reordered across divergent control flow (e.g. warp-synchronous PTX).
Operands
| operand | description |
|---|---|
inputs | input operands to the inline asm |
Result(s):
| result | description |
|---|---|
res | the asm result (a void type when there is none) |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
inline_asm_template | ATTR_KEY_INLINE_ASM_TEMPLATE | StringAttr |
inline_asm_constraints | ATTR_KEY_INLINE_ASM_CONSTRAINTS | StringAttr |
inline_asm_convergent | ATTR_KEY_INLINE_ASM_CONVERGENT | BoolAttr |
Implementations
Sourceimpl InlineAsmOp
impl InlineAsmOp
Sourcepub fn get_attr_inline_asm_template<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, StringAttr>>
pub fn get_attr_inline_asm_template<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>
Get a Ref to the value of the attribute named inline_asm_template.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_inline_asm_template(&self, ctx: &Context, value: StringAttr)
pub fn set_attr_inline_asm_template(&self, ctx: &Context, value: StringAttr)
Set the value of the attribute named inline_asm_template.
Sourcepub fn get_attr_inline_asm_constraints<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, StringAttr>>
pub fn get_attr_inline_asm_constraints<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>
Get a Ref to the value of the attribute named inline_asm_constraints.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_inline_asm_constraints(&self, ctx: &Context, value: StringAttr)
pub fn set_attr_inline_asm_constraints(&self, ctx: &Context, value: StringAttr)
Set the value of the attribute named inline_asm_constraints.
Sourcepub fn get_attr_inline_asm_convergent<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, BoolAttr>>
pub fn get_attr_inline_asm_convergent<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, BoolAttr>>
Get a Ref to the value of the attribute named inline_asm_convergent.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_inline_asm_convergent(&self, ctx: &Context, value: BoolAttr)
pub fn set_attr_inline_asm_convergent(&self, ctx: &Context, value: BoolAttr)
Set the value of the attribute named inline_asm_convergent.
Sourceimpl InlineAsmOp
impl InlineAsmOp
Sourcepub fn new(
ctx: &mut Context,
result_ty: TypeHandle,
inputs: Vec<Value>,
asm_template: &str,
constraints: &str,
convergent: bool,
) -> Self
pub fn new( ctx: &mut Context, result_ty: TypeHandle, inputs: Vec<Value>, asm_template: &str, constraints: &str, convergent: bool, ) -> Self
Create a new InlineAsmOp. Use a void result type for asm with no result value.