InsertValueOp

Struct InsertValueOp 

pub struct InsertValueOp { /* private fields */ }
Equivalent to LLVM’s InsertValue opcode.

Operands

operanddescription
aggregateLLVM aggregate type
valueLLVM type

Result(s):

resultdescription
resLLVM aggregate type

Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
insert_value_indicesATTR_KEY_INSERT_VALUE_INDICESInsertExtractValueIndicesAttr

Implementations

Source

impl InsertValueOp

pub fn get_attr_insert_value_indices<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, InsertExtractValueIndicesAttr>>

Get a Ref to the value of the attribute named insert_value_indices. The Ref is a borrow of the containing Operation object.

pub fn set_attr_insert_value_indices( &self, ctx: &Context, value: InsertExtractValueIndicesAttr, )

Set the value of the attribute named insert_value_indices.

Source

impl InsertValueOp

pub fn new( ctx: &mut Context, aggregate: Value, value: Value, indices: Vec<u32>, ) -> Self

Create a new InsertValueOp. aggregate is the aggregate type and value is the value to insert. indices is the list of indices to insert the value at. The indices must be valid for the given aggregate type.

pub fn indices(&self, ctx: &Context) -> Vec<u32>

Get the indices for inserting value into aggregate.