pub struct InsertValueOp { /* private fields */ }Expand description
Equivalent to LLVM’s InsertValue opcode.
Operands
| operand | description |
|---|---|
aggregate | LLVM aggregate type |
value | LLVM type |
Result(s):
| result | description |
|---|---|
res | LLVM aggregate type |
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
insert_value_indices | ATTR_KEY_INSERT_VALUE_INDICES | InsertExtractValueIndicesAttr |
Implementations
Sourceimpl InsertValueOp
impl InsertValueOp
Sourcepub fn get_attr_insert_value_indices<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, InsertExtractValueIndicesAttr>>
pub fn get_attr_insert_value_indices<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, InsertExtractValueIndicesAttr>>
Get a Ref to the value of the attribute named insert_value_indices.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_insert_value_indices(
&self,
ctx: &Context,
value: InsertExtractValueIndicesAttr,
)
pub fn set_attr_insert_value_indices( &self, ctx: &Context, value: InsertExtractValueIndicesAttr, )
Set the value of the attribute named insert_value_indices.
Sourceimpl InsertValueOp
impl InsertValueOp
Sourcepub fn new(
ctx: &mut Context,
aggregate: Value,
value: Value,
indices: Vec<u32>,
) -> Self
pub fn new( ctx: &mut Context, aggregate: Value, value: Value, indices: Vec<u32>, ) -> Self
Create a new InsertValueOp.
aggregate is the aggregate type and value is the value to insert.
indices is the list of indices to insert the value at.
The indices must be valid for the given aggregate type.